pub struct PruningVerifier;Expand description
Verification utilities for pruning safety.
Implementations
Sourceimpl PruningVerifier
impl PruningVerifier
Sourcepub fn verify_no_resurrection<S: DAGStore>(
store: &S,
pruned: &[Hash],
_snapshot: &Snapshot,
) -> Result<(), String>
pub fn verify_no_resurrection<S: DAGStore>( store: &S, pruned: &[Hash], _snapshot: &Snapshot, ) -> Result<(), String>
Verify that no “live” items would be resurrected after pruning.
This checks that all remove operations that reference pruned nodes are still correctly represented in the post-prune state.